Re: [edk2-devel] [PATCH] OvmfPkg/SmmControl2Dxe: negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG

2020-08-24 Thread Laszlo Ersek
On 08/21/20 15:53, Laszlo Ersek wrote:
> Hi Ard,
> 
> can you please ACK this patch?
> 
> I'm not (necessarily) aiming at the upcoming stable tag, but Igor has
> resumed work on the QEMU-side patches [*], so this is again relevant for
> edk2.
> 
> [*] http://mid.mail-archive.com/20200818122208.1243901-1-imammedo@redhat.com
> https://lists.gnu.org/archive/html/qemu-devel/2020-08/msg03892.html
> 
> (Top-posting because I want to keep the full context intact for you.)
> 
> Thanks!
> Laszlo

Thank you Phil and Ard for the reviews -- because those fit in the
(delayed) SFF deadline, I've gone ahead and merged this patch. Commit
5ba203b54e59, merged via .

Thanks!
Laszlo


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#64576): https://edk2.groups.io/g/devel/message/64576
Mute This Topic: https://groups.io/mt/75505395/21656
Group Owner: devel+ow...@edk2.groups.io
Unsubscribe: https://edk2.groups.io/g/devel/unsub  [arch...@mail-archive.com]
-=-=-=-=-=-=-=-=-=-=-=-



Re: [edk2-devel] [PATCH] OvmfPkg/SmmControl2Dxe: negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG

2020-08-23 Thread Ard Biesheuvel

On 8/21/20 3:53 PM, Laszlo Ersek wrote:

Hi Ard,

can you please ACK this patch?

I'm not (necessarily) aiming at the upcoming stable tag, but Igor has
resumed work on the QEMU-side patches [*], so this is again relevant for
edk2.

[*] http://mid.mail-archive.com/20200818122208.1243901-1-imammedo@redhat.com
https://lists.gnu.org/archive/html/qemu-devel/2020-08/msg03892.html

(Top-posting because I want to keep the full context intact for you.)

Thanks!
Laszlo

On 07/14/20 20:43, Laszlo Ersek wrote:

The ICH9_LPC_SMI_F_BROADCAST and ICH9_LPC_SMI_F_CPU_HOTPLUG feature flags
cause QEMU to behave as follows:

   BROADCAST  CPU_HOTPLUG  use case / behavior
   -  ---  
   clear  clearOVMF built without SMM_REQUIRE; or very old OVMF
   (from before commit a316d7ac91d3 / 2017-02-07).
   QEMU permits CPU hotplug operations, and does
   not cause the OS to inject an SMI upon hotplug.
   Firmware is not expected to be aware of hotplug
   events.

   clear  set  Invalid feature set; QEMU rejects the feature
   negotiation.

   setclearOVMF after a316d7ac91d3 / 2017-02-07, built with
   SMM_REQUIRE, but no support for CPU hotplug.
   QEMU gracefully refuses hotplug operations.

   setset  OVMF after a316d7ac91d3 / 2017-02-07, built with
   SMM_REQUIRE, and supporting CPU hotplug. QEMU
   permits CPU hotplug operations, and causes the
   OS to inject an SMI upon hotplug. Firmware is
   expected to deal with hotplug events.

Negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG -- but only if SEV is disabled, as
OvmfPkg/CpuHotplugSmm can't deal with SEV yet.

Cc: Ard Biesheuvel 
Cc: Boris Ostrovsky 
Cc: Igor Mammedov 
Cc: Jordan Justen 
Cc: Liran Alon 
Cc: Philippe Mathieu-Daudé 
Signed-off-by: Laszlo Ersek 


Acked-by: Ard Biesheuvel 


---

Notes:
 This is the OVMF counterpart to Igor's QEMU series:

 - [RFC 0/3] x86: fix cpu hotplug with secure boot
   https://lists.gnu.org/archive/html/qemu-devel/2020-07/msg03746.html
   message-id: <20200710161704.309824-1-imamm...@redhat.com>

 Repo:   https://pagure.io/lersek/edk2.git
 Branch: negotiate_cpuhp_with_smi_rhbz1849177

  OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf |  1 +
  OvmfPkg/SmmControl2Dxe/SmiFeatures.c  | 26 ++--
  2 files changed, 25 insertions(+), 2 deletions(-)

diff --git a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf 
b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
index 3abed141e644..b8fdea8deb84 100644
--- a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
+++ b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
@@ -46,6 +46,7 @@ [LibraryClasses]
BaseLib
DebugLib
IoLib
+  MemEncryptSevLib
MemoryAllocationLib
PcdLib
PciLib
diff --git a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c 
b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
index 6210b7515e3e..c9d875543205 100644
--- a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
+++ b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
@@ -9,6 +9,7 @@
  
  #include 

  #include 
+#include 
  #include 
  #include 
  #include 
@@ -21,6 +22,12 @@
  // "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg files.
  //
  #define ICH9_LPC_SMI_F_BROADCAST BIT0
+//
+// The following bit value stands for "enable CPU hotplug, and inject an SMI
+// with control value ICH9_APM_CNT_CPU_HOTPLUG upon hotplug", in the
+// "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg files.
+//
+#define ICH9_LPC_SMI_F_CPU_HOTPLUG BIT1
  
  //

  // Provides a scratch buffer (allocated in EfiReservedMemoryType type memory)
@@ -67,6 +74,7 @@ NegotiateSmiFeatures (
UINTNSupportedFeaturesSize;
UINTNRequestedFeaturesSize;
UINTNFeaturesOkSize;
+  UINT64   RequestedFeaturesMask;
  
//

// Look up the fw_cfg files used for feature negotiation. The selector keys
@@ -104,9 +112,16 @@ NegotiateSmiFeatures (
QemuFwCfgReadBytes (sizeof mSmiFeatures, );
  
//

-  // We want broadcast SMI and nothing else.
+  // We want broadcast SMI, SMI on CPU hotplug, and nothing else.
//
-  mSmiFeatures &= ICH9_LPC_SMI_F_BROADCAST;
+  RequestedFeaturesMask = ICH9_LPC_SMI_F_BROADCAST;
+  if (!MemEncryptSevIsEnabled ()) {
+//
+// For now, we only support hotplug with SEV disabled.
+//
+RequestedFeaturesMask |= ICH9_LPC_SMI_F_CPU_HOTPLUG;
+  }
+  mSmiFeatures &= RequestedFeaturesMask;
QemuFwCfgSelectItem (mRequestedFeaturesItem);
QemuFwCfgWriteBytes (sizeof mSmiFeatures, );
  
@@ -144,6 +159,13 @@ NegotiateSmiFeatures (

  DEBUG ((DEBUG_INFO, "%a: using SMI broadcast\n", __FUNCTION__));
}
  
+  if ((mSmiFeatures & 

Re: [edk2-devel] [PATCH] OvmfPkg/SmmControl2Dxe: negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG

2020-08-22 Thread Philippe Mathieu-Daudé
On 7/14/20 8:43 PM, Laszlo Ersek wrote:
> The ICH9_LPC_SMI_F_BROADCAST and ICH9_LPC_SMI_F_CPU_HOTPLUG feature flags
> cause QEMU to behave as follows:
> 
>   BROADCAST  CPU_HOTPLUG  use case / behavior
>   -  ---  
>   clear  clearOVMF built without SMM_REQUIRE; or very old OVMF
>   (from before commit a316d7ac91d3 / 2017-02-07).
>   QEMU permits CPU hotplug operations, and does
>   not cause the OS to inject an SMI upon hotplug.
>   Firmware is not expected to be aware of hotplug
>   events.
> 
>   clear  set  Invalid feature set; QEMU rejects the feature
>   negotiation.
> 
>   setclearOVMF after a316d7ac91d3 / 2017-02-07, built with
>   SMM_REQUIRE, but no support for CPU hotplug.
>   QEMU gracefully refuses hotplug operations.
> 
>   setset  OVMF after a316d7ac91d3 / 2017-02-07, built with
>   SMM_REQUIRE, and supporting CPU hotplug. QEMU
>   permits CPU hotplug operations, and causes the
>   OS to inject an SMI upon hotplug. Firmware is
>   expected to deal with hotplug events.
> 
> Negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG -- but only if SEV is disabled, as
> OvmfPkg/CpuHotplugSmm can't deal with SEV yet.
> 
> Cc: Ard Biesheuvel 
> Cc: Boris Ostrovsky 
> Cc: Igor Mammedov 
> Cc: Jordan Justen 
> Cc: Liran Alon 
> Cc: Philippe Mathieu-Daudé 
> Signed-off-by: Laszlo Ersek 

Reviewed-by: Philippe Mathieu-Daude 

> ---
> 
> Notes:
> This is the OVMF counterpart to Igor's QEMU series:
> 
> - [RFC 0/3] x86: fix cpu hotplug with secure boot
>   https://lists.gnu.org/archive/html/qemu-devel/2020-07/msg03746.html
>   message-id: <20200710161704.309824-1-imamm...@redhat.com>
> 
> Repo:   https://pagure.io/lersek/edk2.git
> Branch: negotiate_cpuhp_with_smi_rhbz1849177
> 
>  OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf |  1 +
>  OvmfPkg/SmmControl2Dxe/SmiFeatures.c  | 26 ++--
>  2 files changed, 25 insertions(+), 2 deletions(-)
> 
> diff --git a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf 
> b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
> index 3abed141e644..b8fdea8deb84 100644
> --- a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
> +++ b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
> @@ -46,6 +46,7 @@ [LibraryClasses]
>BaseLib
>DebugLib
>IoLib
> +  MemEncryptSevLib
>MemoryAllocationLib
>PcdLib
>PciLib
> diff --git a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c 
> b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
> index 6210b7515e3e..c9d875543205 100644
> --- a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
> +++ b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
> @@ -9,6 +9,7 @@
>  
>  #include 
>  #include 
> +#include 
>  #include 
>  #include 
>  #include 
> @@ -21,6 +22,12 @@
>  // "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg 
> files.
>  //
>  #define ICH9_LPC_SMI_F_BROADCAST BIT0
> +//
> +// The following bit value stands for "enable CPU hotplug, and inject an SMI
> +// with control value ICH9_APM_CNT_CPU_HOTPLUG upon hotplug", in the
> +// "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg 
> files.
> +//
> +#define ICH9_LPC_SMI_F_CPU_HOTPLUG BIT1
>  
>  //
>  // Provides a scratch buffer (allocated in EfiReservedMemoryType type memory)
> @@ -67,6 +74,7 @@ NegotiateSmiFeatures (
>UINTNSupportedFeaturesSize;
>UINTNRequestedFeaturesSize;
>UINTNFeaturesOkSize;
> +  UINT64   RequestedFeaturesMask;
>  
>//
>// Look up the fw_cfg files used for feature negotiation. The selector keys
> @@ -104,9 +112,16 @@ NegotiateSmiFeatures (
>QemuFwCfgReadBytes (sizeof mSmiFeatures, );
>  
>//
> -  // We want broadcast SMI and nothing else.
> +  // We want broadcast SMI, SMI on CPU hotplug, and nothing else.
>//
> -  mSmiFeatures &= ICH9_LPC_SMI_F_BROADCAST;
> +  RequestedFeaturesMask = ICH9_LPC_SMI_F_BROADCAST;
> +  if (!MemEncryptSevIsEnabled ()) {
> +//
> +// For now, we only support hotplug with SEV disabled.
> +//
> +RequestedFeaturesMask |= ICH9_LPC_SMI_F_CPU_HOTPLUG;
> +  }
> +  mSmiFeatures &= RequestedFeaturesMask;
>QemuFwCfgSelectItem (mRequestedFeaturesItem);
>QemuFwCfgWriteBytes (sizeof mSmiFeatures, );
>  
> @@ -144,6 +159,13 @@ NegotiateSmiFeatures (
>  DEBUG ((DEBUG_INFO, "%a: using SMI broadcast\n", __FUNCTION__));
>}
>  
> +  if ((mSmiFeatures & ICH9_LPC_SMI_F_CPU_HOTPLUG) == 0) {
> +DEBUG ((DEBUG_INFO, "%a: CPU hotplug not negotiated\n", __FUNCTION__));
> +  } else {
> +DEBUG ((DEBUG_INFO, "%a: CPU hotplug with SMI negotiated\n",
> +  __FUNCTION__));
> +  }
> +
>//
>// Negotiation successful (although we 

Re: [edk2-devel] [PATCH] OvmfPkg/SmmControl2Dxe: negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG

2020-08-21 Thread Laszlo Ersek
Hi Ard,

can you please ACK this patch?

I'm not (necessarily) aiming at the upcoming stable tag, but Igor has
resumed work on the QEMU-side patches [*], so this is again relevant for
edk2.

[*] http://mid.mail-archive.com/20200818122208.1243901-1-imammedo@redhat.com
https://lists.gnu.org/archive/html/qemu-devel/2020-08/msg03892.html

(Top-posting because I want to keep the full context intact for you.)

Thanks!
Laszlo

On 07/14/20 20:43, Laszlo Ersek wrote:
> The ICH9_LPC_SMI_F_BROADCAST and ICH9_LPC_SMI_F_CPU_HOTPLUG feature flags
> cause QEMU to behave as follows:
> 
>   BROADCAST  CPU_HOTPLUG  use case / behavior
>   -  ---  
>   clear  clearOVMF built without SMM_REQUIRE; or very old OVMF
>   (from before commit a316d7ac91d3 / 2017-02-07).
>   QEMU permits CPU hotplug operations, and does
>   not cause the OS to inject an SMI upon hotplug.
>   Firmware is not expected to be aware of hotplug
>   events.
> 
>   clear  set  Invalid feature set; QEMU rejects the feature
>   negotiation.
> 
>   setclearOVMF after a316d7ac91d3 / 2017-02-07, built with
>   SMM_REQUIRE, but no support for CPU hotplug.
>   QEMU gracefully refuses hotplug operations.
> 
>   setset  OVMF after a316d7ac91d3 / 2017-02-07, built with
>   SMM_REQUIRE, and supporting CPU hotplug. QEMU
>   permits CPU hotplug operations, and causes the
>   OS to inject an SMI upon hotplug. Firmware is
>   expected to deal with hotplug events.
> 
> Negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG -- but only if SEV is disabled, as
> OvmfPkg/CpuHotplugSmm can't deal with SEV yet.
> 
> Cc: Ard Biesheuvel 
> Cc: Boris Ostrovsky 
> Cc: Igor Mammedov 
> Cc: Jordan Justen 
> Cc: Liran Alon 
> Cc: Philippe Mathieu-Daudé 
> Signed-off-by: Laszlo Ersek 
> ---
> 
> Notes:
> This is the OVMF counterpart to Igor's QEMU series:
> 
> - [RFC 0/3] x86: fix cpu hotplug with secure boot
>   https://lists.gnu.org/archive/html/qemu-devel/2020-07/msg03746.html
>   message-id: <20200710161704.309824-1-imamm...@redhat.com>
> 
> Repo:   https://pagure.io/lersek/edk2.git
> Branch: negotiate_cpuhp_with_smi_rhbz1849177
> 
>  OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf |  1 +
>  OvmfPkg/SmmControl2Dxe/SmiFeatures.c  | 26 ++--
>  2 files changed, 25 insertions(+), 2 deletions(-)
> 
> diff --git a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf 
> b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
> index 3abed141e644..b8fdea8deb84 100644
> --- a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
> +++ b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
> @@ -46,6 +46,7 @@ [LibraryClasses]
>BaseLib
>DebugLib
>IoLib
> +  MemEncryptSevLib
>MemoryAllocationLib
>PcdLib
>PciLib
> diff --git a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c 
> b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
> index 6210b7515e3e..c9d875543205 100644
> --- a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
> +++ b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
> @@ -9,6 +9,7 @@
>  
>  #include 
>  #include 
> +#include 
>  #include 
>  #include 
>  #include 
> @@ -21,6 +22,12 @@
>  // "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg 
> files.
>  //
>  #define ICH9_LPC_SMI_F_BROADCAST BIT0
> +//
> +// The following bit value stands for "enable CPU hotplug, and inject an SMI
> +// with control value ICH9_APM_CNT_CPU_HOTPLUG upon hotplug", in the
> +// "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg 
> files.
> +//
> +#define ICH9_LPC_SMI_F_CPU_HOTPLUG BIT1
>  
>  //
>  // Provides a scratch buffer (allocated in EfiReservedMemoryType type memory)
> @@ -67,6 +74,7 @@ NegotiateSmiFeatures (
>UINTNSupportedFeaturesSize;
>UINTNRequestedFeaturesSize;
>UINTNFeaturesOkSize;
> +  UINT64   RequestedFeaturesMask;
>  
>//
>// Look up the fw_cfg files used for feature negotiation. The selector keys
> @@ -104,9 +112,16 @@ NegotiateSmiFeatures (
>QemuFwCfgReadBytes (sizeof mSmiFeatures, );
>  
>//
> -  // We want broadcast SMI and nothing else.
> +  // We want broadcast SMI, SMI on CPU hotplug, and nothing else.
>//
> -  mSmiFeatures &= ICH9_LPC_SMI_F_BROADCAST;
> +  RequestedFeaturesMask = ICH9_LPC_SMI_F_BROADCAST;
> +  if (!MemEncryptSevIsEnabled ()) {
> +//
> +// For now, we only support hotplug with SEV disabled.
> +//
> +RequestedFeaturesMask |= ICH9_LPC_SMI_F_CPU_HOTPLUG;
> +  }
> +  mSmiFeatures &= RequestedFeaturesMask;
>QemuFwCfgSelectItem (mRequestedFeaturesItem);
>QemuFwCfgWriteBytes (sizeof mSmiFeatures, );
>  
> @@ -144,6 +159,13 @@ NegotiateSmiFeatures (
>  

[edk2-devel] [PATCH] OvmfPkg/SmmControl2Dxe: negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG

2020-07-14 Thread Laszlo Ersek
The ICH9_LPC_SMI_F_BROADCAST and ICH9_LPC_SMI_F_CPU_HOTPLUG feature flags
cause QEMU to behave as follows:

  BROADCAST  CPU_HOTPLUG  use case / behavior
  -  ---  
  clear  clearOVMF built without SMM_REQUIRE; or very old OVMF
  (from before commit a316d7ac91d3 / 2017-02-07).
  QEMU permits CPU hotplug operations, and does
  not cause the OS to inject an SMI upon hotplug.
  Firmware is not expected to be aware of hotplug
  events.

  clear  set  Invalid feature set; QEMU rejects the feature
  negotiation.

  setclearOVMF after a316d7ac91d3 / 2017-02-07, built with
  SMM_REQUIRE, but no support for CPU hotplug.
  QEMU gracefully refuses hotplug operations.

  setset  OVMF after a316d7ac91d3 / 2017-02-07, built with
  SMM_REQUIRE, and supporting CPU hotplug. QEMU
  permits CPU hotplug operations, and causes the
  OS to inject an SMI upon hotplug. Firmware is
  expected to deal with hotplug events.

Negotiate ICH9_LPC_SMI_F_CPU_HOTPLUG -- but only if SEV is disabled, as
OvmfPkg/CpuHotplugSmm can't deal with SEV yet.

Cc: Ard Biesheuvel 
Cc: Boris Ostrovsky 
Cc: Igor Mammedov 
Cc: Jordan Justen 
Cc: Liran Alon 
Cc: Philippe Mathieu-Daudé 
Signed-off-by: Laszlo Ersek 
---

Notes:
This is the OVMF counterpart to Igor's QEMU series:

- [RFC 0/3] x86: fix cpu hotplug with secure boot
  https://lists.gnu.org/archive/html/qemu-devel/2020-07/msg03746.html
  message-id: <20200710161704.309824-1-imamm...@redhat.com>

Repo:   https://pagure.io/lersek/edk2.git
Branch: negotiate_cpuhp_with_smi_rhbz1849177

 OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf |  1 +
 OvmfPkg/SmmControl2Dxe/SmiFeatures.c  | 26 ++--
 2 files changed, 25 insertions(+), 2 deletions(-)

diff --git a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf 
b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
index 3abed141e644..b8fdea8deb84 100644
--- a/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
+++ b/OvmfPkg/SmmControl2Dxe/SmmControl2Dxe.inf
@@ -46,6 +46,7 @@ [LibraryClasses]
   BaseLib
   DebugLib
   IoLib
+  MemEncryptSevLib
   MemoryAllocationLib
   PcdLib
   PciLib
diff --git a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c 
b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
index 6210b7515e3e..c9d875543205 100644
--- a/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
+++ b/OvmfPkg/SmmControl2Dxe/SmiFeatures.c
@@ -9,6 +9,7 @@
 
 #include 
 #include 
+#include 
 #include 
 #include 
 #include 
@@ -21,6 +22,12 @@
 // "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg files.
 //
 #define ICH9_LPC_SMI_F_BROADCAST BIT0
+//
+// The following bit value stands for "enable CPU hotplug, and inject an SMI
+// with control value ICH9_APM_CNT_CPU_HOTPLUG upon hotplug", in the
+// "etc/smi/supported-features" and "etc/smi/requested-features" fw_cfg files.
+//
+#define ICH9_LPC_SMI_F_CPU_HOTPLUG BIT1
 
 //
 // Provides a scratch buffer (allocated in EfiReservedMemoryType type memory)
@@ -67,6 +74,7 @@ NegotiateSmiFeatures (
   UINTNSupportedFeaturesSize;
   UINTNRequestedFeaturesSize;
   UINTNFeaturesOkSize;
+  UINT64   RequestedFeaturesMask;
 
   //
   // Look up the fw_cfg files used for feature negotiation. The selector keys
@@ -104,9 +112,16 @@ NegotiateSmiFeatures (
   QemuFwCfgReadBytes (sizeof mSmiFeatures, );
 
   //
   // We want broadcast SMI and nothing else.
   //
-  mSmiFeatures &= ICH9_LPC_SMI_F_BROADCAST;
+  RequestedFeaturesMask = ICH9_LPC_SMI_F_BROADCAST;
+  if (!MemEncryptSevIsEnabled ()) {
+//
+// For now, we only support hotplug with SEV disabled.
+//
+RequestedFeaturesMask |= ICH9_LPC_SMI_F_CPU_HOTPLUG;
+  }
+  mSmiFeatures &= RequestedFeaturesMask;
   QemuFwCfgSelectItem (mRequestedFeaturesItem);
   QemuFwCfgWriteBytes (sizeof mSmiFeatures, );
 
@@ -144,6 +159,13 @@ NegotiateSmiFeatures (
 DEBUG ((DEBUG_INFO, "%a: using SMI broadcast\n", __FUNCTION__));
   }
 
+  if ((mSmiFeatures & ICH9_LPC_SMI_F_CPU_HOTPLUG) == 0) {
+DEBUG ((DEBUG_INFO, "%a: CPU hotplug not negotiated\n", __FUNCTION__));
+  } else {
+DEBUG ((DEBUG_INFO, "%a: CPU hotplug with SMI negotiated\n",
+  __FUNCTION__));
+  }
+
   //
   // Negotiation successful (although we may not have gotten the optimal
   // feature set).
@@ -104,9 +112,16 @@ NegotiateSmiFeatures (
 
   //
-  // We want broadcast SMI and nothing else.
+  // We want broadcast SMI, SMI on CPU hotplug, and nothing else.
   //
-- 
2.19.1.3.g30247aa5d201


-=-=-=-=-=-=-=-=-=-=-=-
Groups.io Links: You receive all messages sent to this group.

View/Reply Online (#62561): https://edk2.groups.io/g/devel/message/62561
Mute This Topic: https://groups.io/mt/75505395/21656
Group Owner: devel+ow...@edk2.groups.io